@@ -326,7 +326,7 @@ void KMagZoomView::paintEvent(QPaintEvent *e)
         Qt::black);
 
   p.translate(visibleWidth() / 2.0, visibleHeight() / 2.0);
-  p.setMatrix(m_zoomMatrix, true);
+  p.setWorldTransform(m_zoomMatrix, true);
   const double ratio = 0.5 / m_coloredPixmap.devicePixelRatio();
   p.translate(-m_coloredPixmap.width() * ratio, -m_coloredPixmap.height() * ratio);
   p.drawPixmap(QPoint(clipx-contentsX(), clipy-contentsY()), m_coloredPixmap);
@@ -974,7 +974,7 @@ void KMagZoomView::grabFrame()
 
   // ... but exclude own popups ...
   const QList<QWidget *> siblings = QApplication::topLevelWidgets();
-  foreach (QWidget *sibling, siblings) {
+  for (QWidget *sibling : siblings) {
     if (sibling != window() && (sibling->windowType() & Qt::Window) && sibling->isVisible()) {
       QRect rect = sibling->frameGeometry();
       rect.translate(-selRect.topLeft());
@@ -983,7 +983,7 @@ void KMagZoomView::grabFrame()
   }
 
   QPainter p(&m_coloredPixmap);
-  foreach (const QRect &rect, region.rects()) {
+  for (const QRect &rect : region) {
     p.fillRect(rect, palette().dark());
   }
   p.end();
